@@ -71,7 +71,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         var timerId;
                         this.addListener('appear',function(){
                             timerId = timer.start(function(){
-                                this.fireDataEvent('actionResponse',{action: 'reloadStatus'})
+                                this.fireDataEvent('actionResponse',{action: 'reloadStatus'});
                             }, btCfg.interval * 1000, this);
                         }, this);
                         this.addListener('disappear',function(){
@@ -180,7 +180,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     this.fireEvent('popupClosed');
                                 },this,100);
                                 this.fireDataEvent('actionResponse',{action: 'reload'});
-                            },this)
+                            },this);
                             popup.open();
                             break;
 
