@@ -77,13 +77,24 @@ qx.Class.define("callbackery.ui.plugin.Table", {
                     this.setSelection(model.getRowData(index));
                 },this);
             },this);
-            this._form.addListener('changeData',function(e){
-                selectionModel.resetSelection();
-                model.setFormData(e.getData());
-                model.reloadData();
+            model.addListener('dataChanged',function(e){
+                // it seems we get this event a little early, set the selection
+                // once all pending action has ceassed to be
+                // I guess this is a qx bug ...  dataChanged should
+                // only fire once model actuall HAS new data.
+                window.setTimeout(function(){
+                    selectionModel.setSelectionInterval(0,0);
+                },500);
             });
+            this._form.addListener('changeData',function(e){
+                model.setFormData(e.getData());
+                if (this._loading == 0){ // only reload when data has been changed by human
+                    model.reloadData();
+                }
+            },this);
             this._action.addListener('popupClosed',function(e){
                 model.reloadData();
+                selectionModel.setSelectionInterval(1,1);
             });
             this._action.addListener('actionResponse',function(e){
                 var data = e.getData();
@@ -91,30 +102,12 @@ qx.Class.define("callbackery.ui.plugin.Table", {
                     case 'reload':
                         model.reloadData();
                         break;
+                    case 'dataModified':
+                        model.reloadData();
+                        break;
                 }
             });
             this.add(table,{flex: 1});
-
-        },
-        _loadData: function(){
-            // this.setEnabled(false);
-            var that = this;
-            var rpc = callbackery.data.Server.getInstance();
-            if (this._loading){
-                return;
-            }
-            var form = this._form;
-            var model = this._model;
-            this._loading = true;
-            var parentFormData = {};
-            if (this._getParentFormData){
-                parentFormData = this._getParentFormData();
-            }
-            rpc.callAsyncSmart(function(data){
-                form.setData(data,true);
-                that._loading = false;
-            },'getPluginData',this._cfg.name,'allFields',parentFormData);
         }
     }
-
 });
